=======
audmath
=======

|tests| |coverage| |docs| |python-versions| |license| 

The Python package **audmath** collects mathematical
functions implemented in pure Python,
with **numpy** as it's only external dependency.

Have a look at the installation_ and usage_ instructions as a starting point.


.. _installation: https://audeering.github.io/audmath/installation.html
.. _usage: https://audeering.github.io/audmath/usage.html

.. badges images and links:
.. |tests| image:: https://github.com/audeering/audmath/workflows/Test/badge.svg
    :target: https://github.com/audeering/audmath/actions?query=workflow%3ATest
    :alt: Test status
.. |coverage| image:: https://codecov.io/gh/audeering/audmath/branch/master/graph/badge.svg?token=JFyZlt0Nqk
    :target: https://codecov.io/gh/audeering/audmath
    :alt: code coverage
.. |docs| image:: https://img.shields.io/pypi/v/audmath?label=docs
    :target: https://audeering.github.io/audmath/
    :alt: audmath's documentation
.. |license| image:: https://img.shields.io/badge/license-MIT-green.svg
    :target: https://github.com/audeering/audmath/blob/master/LICENSE
    :alt: audmath's MIT license
.. |python-versions| image:: https://img.shields.io/pypi/pyversions/audmath.svg
    :target: https://pypi.org/project/audmath/
    :alt: audmath's supported Python versions
